==> forestry_1.9.4-5.0.18.165-sources.jar: forestry/factory/inventory/InventoryRainmaker.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.factory.inventory;

import net.minecraft.item.ItemStack;

import forestry.api.fuels.FuelManager;
import forestry.api.fuels.RainSubstrate;
import forestry.core.inventory.InventoryAdapterTile;
import forestry.factory.tiles.TileMillRainmaker;

public class InventoryRainmaker extends InventoryAdapterTile<TileMillRainmaker> {
	private static final int SLOT_SUBSTRATE = 0;

	public InventoryRainmaker(TileMillRainmaker tile) {
		super(tile, 1, "items");
	}

	@Override
	public boolean canSlotAccept(int slotIndex, ItemStack itemStack) {
		if (slotIndex == SLOT_SUBSTRATE) {
			if (FuelManager.rainSubstrate.containsKey(itemStack) && tile.charge == 0 && tile.progress == 0) {
				RainSubstrate substrate = FuelManager.rainSubstrate.get(itemStack);
				if (tile.func_145831_w().func_72896_J() && substrate.isReverse()) {
					return true;
				} else if (!tile.func_145831_w().func_72896_J() && !substrate.isReverse()) {
					return true;
				}
			}
		}

		return false;
	}

	@Override
	public void func_70299_a(int slotIndex, ItemStack itemStack) {
		if (slotIndex == SLOT_SUBSTRATE) {
			RainSubstrate substrate = FuelManager.rainSubstrate.get(itemStack);
			if (substrate != null && substrate.getItem().func_77969_a(itemStack)) {
				tile.addCharge(substrate);
			}
		}
	}
}

==> forestry_1.9-5.0.0.86-sources.jar: forestry/factory/inventory/InventoryRainmaker.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.factory.inventory;

import net.minecraft.item.ItemStack;

import forestry.api.fuels.FuelManager;
import forestry.api.fuels.RainSubstrate;
import forestry.core.inventory.InventoryAdapterTile;
import forestry.factory.tiles.TileMillRainmaker;

public class InventoryRainmaker extends InventoryAdapterTile<TileMillRainmaker> {
	private static final int SLOT_SUBSTRATE = 0;

	public InventoryRainmaker(TileMillRainmaker tile) {
		super(tile, 1, "items");
	}

	@Override
	public boolean canSlotAccept(int slotIndex, ItemStack itemStack) {
		if (slotIndex == SLOT_SUBSTRATE) {
			if (FuelManager.rainSubstrate.containsKey(itemStack) && tile.charge == 0 && tile.progress == 0) {
				RainSubstrate substrate = FuelManager.rainSubstrate.get(itemStack);
				if (tile.getWorld().isRaining() && substrate.isReverse()) {
					return true;
				} else if (!tile.getWorld().isRaining() && !substrate.isReverse()) {
					return true;
				}
			}
		}

		return false;
	}

	@Override
	public void setInventorySlotContents(int slotIndex, ItemStack itemStack) {
		if (slotIndex == SLOT_SUBSTRATE) {
			RainSubstrate substrate = FuelManager.rainSubstrate.get(itemStack);
			if (substrate != null && substrate.getItem().isItemEqual(itemStack)) {
				tile.addCharge(substrate);
			}
		}
	}
}
